@@ -1,4 +1,4 @@
-#' @title Linerange ggplot
+#' Linerange ggplot
 #'
 #' @description Create a linerange ggplot with a wrapper around [ggplot2::ggplot()] + [geom_linerange()][ggplot2::geom_linerange()].
 #'
@@ -8,10 +8,11 @@
 #' @export
 #'
 #' @examples
-#'
 #' library(ggplot2)
 #' library(dplyr)
 #'
+#' set_blanket()
+#'
 #' data.frame(
 #'   trt = factor(c(1, 1, 2, 2)),
 #'   resp = c(1, 5, 3, 4),
@@ -45,7 +46,7 @@ gg_linerange <- function(
     yend = NULL,
     z = NULL,
     col = NULL,
-    alpha = NULL,
+    # alpha = NULL,
     facet = NULL,
     facet2 = NULL,
     group = NULL,
@@ -86,18 +87,6 @@ gg_linerange <- function(
     col_steps = FALSE,
     col_title = NULL,
     col_transform = NULL,
-    alpha_breaks = NULL,
-    alpha_expand_limits = NULL,
-    alpha_labels = NULL,
-    alpha_legend_ncol = NULL,
-    alpha_legend_nrow = NULL,
-    alpha_legend_rev = FALSE,
-    alpha_limits = NULL,
-    alpha_oob = scales::oob_keep,
-    alpha_pal = NULL,
-    alpha_pal_na = NA,
-    alpha_title = NULL,
-    alpha_transform = NULL,
     facet_axes = NULL,
     facet_axis_labels = "margins",
     facet_labels = NULL,
@@ -131,7 +120,7 @@ gg_linerange <- function(
     yend = {{ yend }},
     z = {{ z }},
     col = {{ col }},
-    alpha = {{ alpha }},
+    # alpha = {{ alpha }},
     facet = {{ facet }},
     facet2 = {{ facet2 }},
     group = {{ group }},
@@ -172,18 +161,6 @@ gg_linerange <- function(
     col_steps = col_steps,
     col_title = col_title,
     col_transform = col_transform,
-    alpha_breaks = alpha_breaks,
-    alpha_expand_limits = alpha_expand_limits,
-    alpha_labels = alpha_labels,
-    alpha_legend_ncol = alpha_legend_ncol,
-    alpha_legend_nrow = alpha_legend_nrow,
-    alpha_legend_rev = alpha_legend_rev,
-    alpha_limits = alpha_limits,
-    alpha_oob = alpha_oob,
-    alpha_pal = alpha_pal,
-    alpha_pal_na = alpha_pal_na,
-    alpha_title = alpha_title,
-    alpha_transform = alpha_transform,
     facet_axes = facet_axes,
     facet_axis_labels = facet_axis_labels,
     facet_labels = facet_labels,
