@@ -1,4 +1,4 @@
-#' @title Point ggplot
+#' Point ggplot
 #'
 #' @description Create a point ggplot with a wrapper around [ggplot2::ggplot()] + [geom_point()][ggplot2::geom_point()].
 #'
@@ -8,19 +8,18 @@
 #' @export
 #'
 #' @examples
-#'
 #' library(ggplot2)
 #' library(dplyr)
 #' library(palmerpenguins)
 #'
+#' set_blanket()
+#'
 #' penguins |>
 #'   mutate(across(sex, \(x) stringr::str_to_sentence(x))) |>
 #'   gg_point(
 #'     x = flipper_length_mm,
 #'     y = body_mass_g,
 #'     col = sex,
-#'     facet = species,
-#'     mode = light_mode_b(),
 #'   )
 #'
 gg_point <- function(
@@ -40,7 +39,7 @@ gg_point <- function(
     yend = NULL,
     z = NULL,
     col = NULL,
-    alpha = NULL,
+    # alpha = NULL,
     facet = NULL,
     facet2 = NULL,
     group = NULL,
@@ -81,18 +80,6 @@ gg_point <- function(
     col_steps = FALSE,
     col_title = NULL,
     col_transform = NULL,
-    alpha_breaks = NULL,
-    alpha_expand_limits = NULL,
-    alpha_labels = NULL,
-    alpha_legend_ncol = NULL,
-    alpha_legend_nrow = NULL,
-    alpha_legend_rev = FALSE,
-    alpha_limits = NULL,
-    alpha_oob = scales::oob_keep,
-    alpha_pal = NULL,
-    alpha_pal_na = NA,
-    alpha_title = NULL,
-    alpha_transform = NULL,
     facet_axes = NULL,
     facet_axis_labels = "margins",
     facet_labels = NULL,
@@ -126,7 +113,7 @@ gg_point <- function(
     yend = {{ yend }},
     z = {{ z }},
     col = {{ col }},
-    alpha = {{ alpha }},
+    # alpha = {{ alpha }},
     facet = {{ facet }},
     facet2 = {{ facet2 }},
     group = {{ group }},
@@ -167,18 +154,6 @@ gg_point <- function(
     col_steps = col_steps,
     col_title = col_title,
     col_transform = col_transform,
-    alpha_breaks = alpha_breaks,
-    alpha_expand_limits = alpha_expand_limits,
-    alpha_labels = alpha_labels,
-    alpha_legend_ncol = alpha_legend_ncol,
-    alpha_legend_nrow = alpha_legend_nrow,
-    alpha_legend_rev = alpha_legend_rev,
-    alpha_limits = alpha_limits,
-    alpha_oob = alpha_oob,
-    alpha_pal = alpha_pal,
-    alpha_pal_na = alpha_pal_na,
-    alpha_title = alpha_title,
-    alpha_transform = alpha_transform,
     facet_axes = facet_axes,
     facet_axis_labels = facet_axis_labels,
     facet_labels = facet_labels,
