@@ -1,4 +1,4 @@
-#' @title Ribbon ggplot
+#' Ribbon ggplot
 #'
 #' @description Create a ribbon ggplot with a wrapper around [ggplot2::ggplot()] + [geom_ribbon()][ggplot2::geom_ribbon()]
 #'
@@ -8,22 +8,23 @@
 #' @export
 #'
 #' @examples
-#'
 #' library(ggplot2)
 #' library(dplyr)
 #'
+#' set_blanket()
+#'
 #' data.frame(year = 1875:1972, level = as.vector(LakeHuron)) |>
 #'   mutate(level_min = level - 1, level_max = level + 1) |>
 #'   gg_ribbon(
 #'     x = year,
 #'     ymin = level_min,
 #'     ymax = level_max,
+#'     colour = NA,
+#'     x_labels = \(x) x,
 #'     y_title = "Level",
-#'     col_pal = scales::alpha(blue, 0),
 #'   ) +
 #'   geom_line(
-#'     mapping = aes(x = year, y = level),
-#'     colour = blue,
+#'     mapping = aes(y = level),
 #'   )
 #'
 gg_ribbon <- function(
@@ -43,7 +44,7 @@ gg_ribbon <- function(
     yend = NULL,
     z = NULL,
     col = NULL,
-    alpha = NULL,
+    # alpha = NULL,
     facet = NULL,
     facet2 = NULL,
     group = NULL,
@@ -84,18 +85,6 @@ gg_ribbon <- function(
     col_steps = FALSE,
     col_title = NULL,
     col_transform = NULL,
-    alpha_breaks = NULL,
-    alpha_expand_limits = NULL,
-    alpha_labels = NULL,
-    alpha_legend_ncol = NULL,
-    alpha_legend_nrow = NULL,
-    alpha_legend_rev = FALSE,
-    alpha_limits = NULL,
-    alpha_oob = scales::oob_keep,
-    alpha_pal = NULL,
-    alpha_pal_na = NA,
-    alpha_title = NULL,
-    alpha_transform = NULL,
     facet_axes = NULL,
     facet_axis_labels = "margins",
     facet_labels = NULL,
@@ -129,7 +118,7 @@ gg_ribbon <- function(
     yend = {{ yend }},
     z = {{ z }},
     col = {{ col }},
-    alpha = {{ alpha }},
+    # alpha = {{ alpha }},
     facet = {{ facet }},
     facet2 = {{ facet2 }},
     group = {{ group }},
@@ -170,18 +159,6 @@ gg_ribbon <- function(
     col_steps = col_steps,
     col_title = col_title,
     col_transform = col_transform,
-    alpha_breaks = alpha_breaks,
-    alpha_expand_limits = alpha_expand_limits,
-    alpha_labels = alpha_labels,
-    alpha_legend_ncol = alpha_legend_ncol,
-    alpha_legend_nrow = alpha_legend_nrow,
-    alpha_legend_rev = alpha_legend_rev,
-    alpha_limits = alpha_limits,
-    alpha_oob = alpha_oob,
-    alpha_pal = alpha_pal,
-    alpha_pal_na = alpha_pal_na,
-    alpha_title = alpha_title,
-    alpha_transform = alpha_transform,
     facet_axes = facet_axes,
     facet_axis_labels = facet_axis_labels,
     facet_labels = facet_labels,
